# -*- coding: utf-8 -*-
import csv
import json
import copy
from itam_assistant1.do_ai import do_ai_auto

# 假设 Testsuitelink 是一个有效的文档链接
from itam_assistant1.openapi import get_query_vector

Testsuitelink = "your_testsuitelink_here"

try:
    startAt, row_count = do_ai_auto(Testsuitelink)
    if startAt is not None and row_count is not None:
        print(f"成功执行，startAt: {startAt}, row_count: {row_count}")
    else:
        print("执行过程中出现错误")
except Exception as e:
    print(f"调用 do_ai_auto 函数时出现异常: {e}")

def _test():
    #读取本地文件 读取software.csv 获取description_zh字段
    description_zh_list = []
    file_path = 'data/software_spu.csv'
    with open(file_path, 'r', encoding='utf-8', newline='') as file:
        reader = csv.DictReader(file)
        for row in reader:
            if row['description_zh'] != "--":
                res = json.loads(get_query_vector(0.6, [row['description_zh']], 10, "vec_description"))
                lista = {'score': '', 'label': ''}
                res_label = []
                for j in res['body']['Results']:
                    lista['label'] = j['Item']['name_en']
                    lista['score'] = j['Score']
                    res_label.append(copy.deepcopy(lista))
                    info0 = {
                        "input": {"用户输入/userInput": "我想申请" + row['name_en']},  # 每条用例的输入
                        "output": {"用户输入/output": "我想申请" + row['name_en']},  # 每条用例的输出
                        "rt": "True",  # 用例的人工人为的结果 True/Flase
                        "label": res_label,  # 用例的评测指标，如技能识别,实际的输出,如有
                        "exp": res_label,  # ，如技能识别,用例打标
                        "artificial": res_label  # ，人工标准的值，如有
                    }

                description_zh_list.append(copy.deepcopy(info0))
                print(len(description_zh_list))

        #将description_zh_list写入本地文件
    with open('../test_data/software_spu_resxxxxxx.json', 'w') as file:
        json.dump(description_zh_list, file, ensure_ascii=False)


    """

    #创建csv并写入值
    with open('data/software_spu_res1.csv', 'w', newline='') as file:
        writer = csv.writer(file)
        # 写入表头
        writer.writerow(['用户输入/userInput', '用户输入/output', 'rt', 'label0', 'score0','label1','score1','label2','score2','label3','score3','label4','score4','label5','score5','label6','score6','label7','score7','label8','score8','label9','score9'])
        # 写入数据
        for info in description_zh_list:
            input_text = info['input']['用户输入/userInput']
            output_text = info['output']['用户输入/output']
            rt = info['rt']
            row_data = [input_text, output_text, rt]
            labels = info['label']
            for i in range(10):
                if i < len(labels):
                    row_data.extend([labels[i]['label'], labels[i]['score']])
                else:
                    row_data.extend(['', ''])
            writer.writerow(row_data)
    """





import os
import logging.config

config = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '%(asctime)s %(levelname)s %(message)s'
        }
    },
    'loggers': {
        'playground': {
            'handlers': ['log_agent', 'console', 'kafka_agent'],
            'propagate': False,
            'level': 'INFO',
        },
        'root': {
            'handlers': ['log_agent', 'console'],
            'level': 'INFO'
        }
    },
    'handlers': {
        'log_agent': {
            'level': 'INFO',
            'class': 'bytedlogger.StreamLogHandler',
            'tags': {
                'customtag': 'devops_boe',
            }
        },
        'kafka_agent': {
            'level': 'INFO',
            'class': 'kafkalogger.handlers.KafkaLogHandler',
            'formatter': 'default',
        },
        'console': {
            'level': 'INFO',
            'class': 'logging.StreamHandler',
        }
    },

}
if os.getenv("DEBUG") == "true":
    config["handlers"].pop("kafka_agent")
    config["handlers"].pop("log_agent")
    config["loggers"]["playground"]["handlers"].remove("kafka_agent")
    config["loggers"]["playground"]["handlers"].remove("log_agent")
    config['loggers']['root']['handlers'].remove("log_agent")
logging.config.dictConfig(config)
logger = logging.getLogger('playground')
logging.getLogger("kafka").setLevel(logging.CRITICAL)
logging.getLogger("bytedkafka.common.config").setLevel(logging.ERROR)
logging.getLogger("kafka.producer.kafka").setLevel(logging.ERROR)



["鼠标","显示器双C数据线","Type-C扩展坞","西部数据-WDBEPK0020BBK","鼠标和键盘","鼠标","鼠标","鼠标","笔记本充电器","笔记本充电器","鼠标","And crown-PTH-660/K0-F","mouse and keyboard","hdmi dongle","笔记本支架","蓝牙键盘","mac蓝牙鼠标","鼠标耳机键盘","显示器双C数据线","鼠标","鼠标","鼠标键盘","Adapter","外置硬盘","keyboard","笔记本充电器","鼠标和键盘","Type-C扩展坞","65W笔记本电源","安卓手机数据线","笔记本电源","keyboard","鼠标和键盘","SanDisk-SDSSDE81-4T00-Z25"]


# -*- coding: utf-8 -*-
import time
from itam_assistant.ailyapp_client import AilyLarkClient
from itam_assistant.lark_client import LarkdocsClient
from itam_assistant.intent_detail import *
from itam_assistant.openapi import *
import datetime
import copy
import os
import csv


# 定义一个全局变量Client
# Testsuitelink = "https://bytedance.larkoffice.com/sheets/ZVzfsw4rMhkMF6tjtxmc4BdSnMb"


def do_ai_auto(Testk_data, clientinfo):
    """
    自动化执行AI测试用例
    """
    startAt = 0
    try:

        # 判断Testsuitelink中是否包含https://
        if "https://" in Testk_data:

            # 通过文档链接获取spreadsheet_token
            spreadsheet_token = Testk_data.split("/")[-1]
            if not spreadsheet_token:
                raise ValueError("未能从文档链接中提取到有效的spreadsheet_token")
            # 读取表格用户输入
            spreadsheet = LarkdocsClient().get_the_worksheet(spreadsheet_token)
            if not spreadsheet:
                raise ValueError("未能获取到有效的工作表数据")
            for i in spreadsheet.sheets:
                column_count = i.grid_properties.column_count
                row_count = i.grid_properties.row_count
                sheet_id = i.sheet_id
                title = i.title
                if title == "测试集":
                    # 构建JSON字符串
                    json_str = {"ranges": [sheet_id + "!A1:A" + str(row_count)]}
                    # 获取纯文本内容
                    test = LarkdocsClient().get_plaintextcontent(json_str, spreadsheet_token, sheet_id)
                    test = json.loads(test)
                    userinput = test['data']['value_ranges'][0]['values']
                    print(f"表头为{userinput[0]}")
                    # 获取租户访问令牌
                    tenant_access_token = AilyLarkClient(clientinfo).get_tenant_access_token()
                    if not tenant_access_token:
                        raise ValueError("未能获取到有效的租户访问令牌")
                    for i in range(1, row_count):
                        if userinput[i][0]:
                            if startAt == 0:
                                startAt = int(time.time())
                            # 创建会话
                            seseion_id = AilyLarkClient(clientinfo).create_ailysession(tenant_access_token)
                            if not seseion_id:
                                raise ValueError("未能成功创建会话")
                            # 创建消息
                            message_id = AilyLarkClient(clientinfo).create_ailysessionaily_message(tenant_access_token,
                                                                                                   seseion_id,
                                                                                                   userinput[i][0])
                            if not message_id:
                                raise ValueError("未能成功创建消息")
                            # 创建运行实例
                            runs = AilyLarkClient(clientinfo).create_ailysession_run(tenant_access_token, seseion_id)
                            # 可不需等待运行实例创建完成
                            # if not runs:
                            #    raise ValueError("未能成功创建运行实例")
                            time.sleep(2)
                        else:
                            return startAt, i
                            break
                    return startAt, row_count
                    break
        elif Testk_data[0].get('ext'):
            num = 0
            for i in Testk_data:
                # 获取租户访问令牌
                tenant_access_token = AilyLarkClient(clientinfo).get_tenant_access_token()
                if not tenant_access_token:
                    raise ValueError("未能获取到有效的租户访问令牌")
                if i['ext'].get('input'):
                    aa = i['ext']['input']
                else:
                    aa = i['ext']['用户输入']                    
                if startAt == 0:
                    startAt = int(time.time())
                # 创建会话
                seseion_id = AilyLarkClient(clientinfo).create_ailysession(tenant_access_token)
                time.sleep(3)
                if not seseion_id:
                    raise ValueError("未能成功创建会话")
                # 创建消息
                message_id = AilyLarkClient(clientinfo).create_ailysessionaily_message(tenant_access_token, seseion_id,
                                                                                       aa)
                time.sleep(3)
                if not message_id:
                    raise ValueError("未能成功创建消息")
                # 创建运行实例
                runs = AilyLarkClient(clientinfo).create_ailysession_run(tenant_access_token, seseion_id)
                time.sleep(4)
                num = num + 1
                time.sleep(4)
            return startAt, num
    except KeyError as ke:
        print(f"KeyError 发生: 数据中缺少必要的键，错误详情: {ke}")
        return None, None
    except json.JSONDecodeError as jde:
        print(f"JSON 解析错误: {jde}")
        return None, None
    except ValueError as ve:
        print(f"值错误: {ve}")
        return None, None
    except Exception as e:
        print(f"发生未知错误: {e}")
        return None, None


def get_results(num,res):
    """
    获取结果
    """
    labels = []
    a = len(res["body"]["Results"])
    #判断res["body"]["Results"]的个数，如果大于num，则取num个值，小于num，则取res["body"]["Results"]的个数
    if a > num:
        num = num
    else:
        num = a
    #提取res["body"]["Results"]的前num个值
    res["body"]["Results"] = res["body"]["Results"][:num]
    #遍历res["body"]["Results"]提取 name_zh、brand_zh、model_zh、specification_zh 并拼接
    for i in range(0, num):
        res["body"]["Results"][i]['Item']['sku_zh'] = res["body"]["Results"][i]['Item']['name_zh'] + " " + res["body"]["Results"][i]['Item']['brand_zh'] + " " + res["body"]["Results"][i]['Item']['model_zh'] + " " + res["body"]["Results"][i]['Item']['specification_zh']
        label = {"label" :res["body"]["Results"][i]['Item']['sku_zh'], "score" : res["body"]["Results"][i]['Score']}
        labels.append(copy.deepcopy(label))
    return labels



def do_waterlevellineres_list(res, info):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
        return info

    # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
    if res["body"]["Results"]:
        info['output']['用户输入/output']='log_id:'+res['log_id']
        # 取["Results"]下前2个结果，若只有1个结果，label1为空
        if len(res["body"]["Results"]) > 0:
            for j in range(len(res["body"]["Results"])):
                aaa = {'label': res["body"]["Results"][j]['Item']['name_zh']+"&"+res["body"]["Results"][j]['Item']['brand_zh']+"&"+res["body"]["Results"][j]['Item']['model_zh']+"&"+res["body"]["Results"][j]['Item']['specification_zh'],
                       'score': res["body"]["Results"][j]['Score']}
                info['label'].append(copy.deepcopy(aaa))
        # 判断label0和label1是否为空，为空则：label默认2级
        # 判断exp和label是否一致，一致则：rt=True，不一致则：rt=False
        if info['exp'][0]['label'] == info['label'][0]['label'] and info['exp'][1]['label'] == info['label'][1][
            'label'] and info['exp'][0]['score'] <= info['label'][0]['score'] and info['exp'][1]['score'] <= \
                info['label'][1]['score']:
            info['rt'] = True
        else:
            info['rt'] = False

    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False

    return info

def do_waterlevellineres_listv2(res, info):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
        return info
    reslist = res["body"]["Results"]
    info['output']['用户输入/output'] = 'log_id:' + res.get('log_id') or res.get('requestId')
    if reslist:
        #取所有结果并追加到info['label']
        info['label'] = []
        if len(reslist) > 0:
            for j in range(len(reslist)):
                aaa = {'label': reslist[j]['Item']['name_zh'],
                       'score': reslist[j]['Score'],
                       'info':reslist[j]['Item']['name_zh']+"&"+reslist[j]['Item']['brand_zh']+"&"+reslist[j]['Item']['model_zh']+"&"+reslist[j]['Item']['specification_zh'],}
                info['label'].append(copy.deepcopy(aaa))
        # 判断exp和label是否一致，一致则：rt=True，不一致则：rt=False
        for a in range(len(info['exp'])):
            if info['exp'][a]['label']== info['label'][a]['label']:
                info['rt'] = True
            else:
                info['rt'] = False
                break
    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False

    return info

def do_waterlevellineres_listassetspu(res, info,hardtype):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}]
        info['rt'] = False
        return info
    if res["data"].get("AiBorrowAndUseResponseList") == None:
        info['label'] = [{'label': '', 'score': 0},{'label': '', 'score': 0.8}]
        info['rt'] = False
        if info['exp']==[]:
            info['rt'] = True
        return info
    reslist=res["data"]["AiBorrowAndUseResponseList"]
    info['output']['用户输入/output']='requestId:'+res['requestId']
    aaa ={}
    # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
    if reslist:
        # 取["Results"]下前2个结果，若只有1个结果，label1为空
        if len(reslist) > 0:
           for j in range(len(reslist)):
               if hardtype==2:
                   aaa = {'label': reslist[j]['AccessoryModelScope']['AccessoryModelInfo']['Name']['ValueZh'],
                          'score': reslist[j]['Score']}
                   info['label'].append(copy.deepcopy(aaa))
               if hardtype == 1:
                   aaa = {'label': reslist[j]['AssetModelScope']['SpuNameZh'] or reslist[j]['AssetModelScope']['NameZh']+reslist[j]['AssetModelScope']['ModelZh']+reslist[j]['AssetModelScope']['SpecificationZh'],
                          'score': reslist[j]['Score']}
                   info['label'].append(copy.deepcopy(aaa))
        # 判断label0和label1是否为空，为空则：label默认2级
        for a in range(len(info['exp'])):
            if info['exp'][a]['label'] == info['label'][a]['label']:
                info['rt'] = True
            else:
                info['rt'] = False
                break
    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
    return info

def do_waterlevellineres_listassetspu_pre(res, info,hardtype):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}]
        info['rt'] = False
        return info
    if res.get("body") == None:
        info['label'] = [{'label': '', 'score': 0},{'label': '', 'score': 0.8}]
        info['rt'] = False
        if info['exp'][0]['label']=='':
            info['rt'] = True
        return info
    reslist=res["body"]
    aaa ={}
    # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
    if reslist:
        # 取["Results"]下前2个结果，若只有1个结果，label1为空
        if len(reslist) > 0:
           for j in range(len(reslist)):
               if hardtype==2:
                   aaa = {'label': reslist[j]['AccessoryModelScope']['AccessoryModelInfo']['Name']['ValueZh'],
                          'score': reslist[j]['Score']}
                   info['label'].append(copy.deepcopy(aaa))
               if hardtype == 1:
                   aaa = {'label': reslist[j]['Item']['name_zh']+reslist[j]['Item']['brand_zh']+reslist[j]['Item']['model_zh']+reslist[j]['Item']['specification_zh'],
                          'score': reslist[j]['Score']}
                   info['label'].append(copy.deepcopy(aaa))
        # 判断label0和label1是否为空，为空则：label默认2级
        # 判断exp和label是否一致，一致则：rt=True，不一致则：rt=False
        if info['exp'][0]['label'] == info['label'][0]['label'] and info['exp'][1]['label'] == info['label'][1][
            'label'] and info['exp'][0]['score'] <= info['label'][0]['score'] and info['exp'][1]['score'] <= \
                info['label'][1]['score']:
            info['rt'] = True
        else:
            info['rt'] = False
    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
    return info

def do_waterlevellineres_sr(res, info,hardtype):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}]
        info['rt'] = False
        return info
    if res["data"].get("AiBorrowAndUseResponseList") == None:
        info['label'] = [{'label': '', 'score': 0},{'label': '', 'score': 0.8}]
        info['rt'] = False
        if info['exp'][0]['label']=='':
            info['rt'] = True
        return info
    reslist=res["data"]["AssetModels"]
    aaa ={}
    # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
    if reslist:
        # 取["Results"]下前2个结果，若只有1个结果，label1为空
        if len(reslist) > 0:
           for j in range(len(reslist)):
               if hardtype==2:
                   aaa = {'label': reslist[j]['AccessoryModelScope']['AccessoryModelInfo']['Name']['ValueZh'],
                          'score': reslist[j]['Score']}
                   info['label'].append(copy.deepcopy(aaa))
               if hardtype == 1:
                   aaa = {'label': reslist[j]['SpuNameZh'] or reslist[j]['NameZh']+reslist[j]['ModelZh']+reslist[j]['SpecificationZh'],
                          'score': 0.5}
                   info['label'].append(copy.deepcopy(aaa))
        # 判断label0和label1是否为空，为空则：label默认2级
        # 判断exp和label是否一致，一致则：rt=True，不一致则：rt=False
           # 判断label0和label1是否为空，为空则：label默认2级
        for a in range(len(info['exp'])):
            if info['exp'][a]['label'] == info['label'][a]['label']:
                   info['rt'] = True
            else:
                   info['rt'] = False
                   break
    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
    return info


def do_metricsevaluation_list(collections,data,score_threshold):
    """
    指标 评测
    """
    info = {
        "input": {
            "用户输入": "测试数据"
        },
        "output": {
            "output": "测试数据"
        },
        "rt": False,
        "label": [{"label": "测试"}, {"label": "测试"}],
        "exp": [{"label": "测试"}, {"label": "测试" }],
        "artificial": []
    }
    info_list = []
    businessscenario = []
    for i in collections:
        for j in data:
            cleaned_content = i['content'].replace('\r', '').replace('\n', '').replace('\\', '')
            cleaned_userInput = j['用户输入/userInput'].replace('\r', '').replace('\n', '').replace('\\', '')
            if cleaned_content == cleaned_userInput:
                info['input']['用户输入'] = i['ext'].get('input') or i['ext']['用户输入']
                info['output']['output'] = "对话id："+j['对话日志/intentID']+"    对话内容："+j['用户输入/userInput']
                if i['ext']['分发技能'] != '' and i['ext']['分发技能'] in j['分发技能/skill'][0]:
                    info['rt'] = True
                    info['label'] = [{'label': j['分发技能/skill'][0]}]
                    info['exp'] = [{'label': i['ext']['分发技能']}]
                    info['artificial'] = info['exp']
                else:
                    info['rt'] = False
                    info['label'] = [{'label': j['分发技能/skill'][0]}]
                    info['exp'] = [{'label': i['ext']['分发技能']}]
                    info['artificial'] = info['exp']
                if i['ext']['分发技能'] not in businessscenario:
                    businessscenario.append(i['ext']['分发技能'])
                #将data中的j删除
                data.remove(j)
                info_list.append(copy.deepcopy(info))
                print(info)
                break
    return info_list,businessscenario


def do_scenereview_list(collections,data,score_threshold):
    """
    场景 评测  提取关键词
    """
    score_threshold=0.8
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8 }],
        "artificial": []
    }
    info_list = []
    for i in collections:
        for j in data:
            if i['content'] == j['用户输入/userInput']:
                info['input']['用户输入/userInput'] = i['ext']['output']
                info['output']['用户输入/output'] = j['用户输入/userInput']
                if i['ext']['BPO标注-AP-资产名称'] == j['llm关键词']:
                    info['rt'] = True
                    info['label'] = [{'label': str(j['llm关键词']), 'score': score_threshold}]
                else:
                    info['rt'] = False
                    info['label'] = [{'label': str(i['ext']['BPO标注-AP-资产名称']), 'score': score_threshold}]
                info['exp'] = [{'label': str(i['ext']['BPO标注-AP-资产名称']), 'score': score_threshold}]
                info['artificial'] = info['exp']
    info_list.append(copy.deepcopy(info))
    return info_list

def do_waterlevelline_autotest(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
        info['exp'] = []
        for j in [i['ext']['BPO标注-AP-资产型号'], i['ext'].get('BPO标注-AP-资产型号1'),i['ext'].get('BPO标注-AP-资产型号2'),i['ext'].get('BPO标注-AP-资产型号3'),i['ext'].get('BPO标注-AP-资产型号4'),i['ext'].get('BPO标注-AP-资产型号5'),i['ext'].get('BPO标注-AP-资产型号6'),i['ext'].get('BPO标注-AP-资产型号7'),i['ext'].get('BPO标注-AP-资产型号8'),i['ext'].get('BPO标注-AP-资产型号9'),i['ext'].get('BPO标注-AP-资产型号10')]:
            if j:
                info['exp'].append({'label': j, 'score': score_threshold})
        #判断i['ext']['BPO标注-AP-资产型号']是否为空，为空就不用读取，不为空就读取
        if i['ext']['BPO标注-AP-资产型号']:
            asset_name = i['ext']['BPO标注-AP-资产名称']
            try:
                if isinstance(asset_name, str):
                    asset_name = json.loads(asset_name)
            except json.JSONDecodeError:
                # 若解析失败，说明不是 JSON 格式，保持原样
                pass
        info['artificial'] = info['exp']
        if i['ext']['BPO标注-AP-资产名称']:
            asset_name = i['ext']['BPO标注-AP-资产名称']
            try:
                if isinstance(asset_name, str):
                    asset_name = json.loads(asset_name)
            except json.JSONDecodeError:
                # 若解析失败，说明不是 JSON 格式，保持原样
                pass
            if "软件申请" in i['ext']['BPO标注-AP-分发技能']:
                keywprd = software_asset_sku_structure(asset_name)
                res = json.loads(get_query_vector(keywprd, clientinfo))
            if "设备/配件申请" in i['ext']['BPO标注-AP-分发技能']:
                #keywprd = equipmentrequest_structure(asset_name, i['ext']['asset_type'])
                keywprd = {
    "From": 0,
    "Size": 10,
    "MinScore": 0.7,
    "AssetModelFieldsWithAnd": [
        {
            "FieldName": "vec_search",
            "FieldType": "knn",
            "QueryValue": [
                asset_name
            ]
        }
    ],
    "SPUIDs": None,
    "AssetModelBizTypes": [
        "asset_sku"
    ]
}
                res = json.loads(get_query_vector(keywprd, clientinfo))
                #res = get_by_AssetModelBizTypes(keywprd,res0)
            if "设备/配件退还" in i['ext']['BPO标注-AP-分发技能']:
                keywprd = equipmentreturn_structure0(asset_name, i['ext']['asset_type'])
                res0 = json.loads(get_query_vector(keywprd, clientinfo))
                res = get_by_AssetModelBizTypes(keywprd, res0)
        else:
            res = ""
        infoout = do_waterlevellineres_listv2(res, info)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list

def do_waterlevelline_autotest_aseetspu(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
        info['exp'] = []
        for j in [i['ext']['BPO标注-AP-资产型号'], i['ext'].get('BPO标注-AP-资产型号1'),
                  i['ext'].get('BPO标注-AP-资产型号2'), i['ext'].get('BPO标注-AP-资产型号3'),
                  i['ext'].get('BPO标注-AP-资产型号4'), i['ext'].get('BPO标注-AP-资产型号5'),
                  i['ext'].get('BPO标注-AP-资产型号6'), i['ext'].get('BPO标注-AP-资产型号7'),
                  i['ext'].get('BPO标注-AP-资产型号8'), i['ext'].get('BPO标注-AP-资产型号9'),
                  i['ext'].get('BPO标注-AP-资产型号10')]:
            if j:
                info['exp'].append({'label': j, 'score': score_threshold})
        info['artificial'] = info['exp']
        info['label']=[]
        if i['ext']['BPO标注-AP-资产名称']:
            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
                asset_name = i['ext']['BPO标注-AP-资产名称']
                try:
                    # 尝试将其解析为 JSON 对象
                    if isinstance(asset_name, str):
                        asset_name0 = json.loads(asset_name)
                        asset_name = asset_name0['asset_name']
                except json.JSONDecodeError:
                    # 若解析失败，说明不是 JSON 格式，保持原样
                    pass
                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
                if i['ext']['BPO标注-AP-资产类型'] == "设备":
                    hardtype = 1
                elif  i['ext']['BPO标注-AP-资产类型'] == "配件" or  i['ext']['BPO标注-AP-资产类型'] == '2.0' :
                    hardtype = 2
                res = GetBestMatchItemonline(key,hardtype,clientinfo)
        else:
            res = ""
        infoout = do_waterlevellineres_listassetspu(res, info,hardtype)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list

def do_waterlevelline_autotest_aseetspu_old(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
        info['exp'] = [
            {'label': i['ext']['BPO标注-AP-资产型号'], 'score': score_threshold},
            {'label': i['ext'].get('BPO标注-AP-资产型号1', ''), 'score': score_threshold}]
        info['artificial'] = info['exp']
        info['label']=[]
        if i['ext']['BPO标注-AP-资产名称']:
            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
                asset_name = i['ext']['BPO标注-AP-资产名称']
                asset_name = i['ext']['BPO标注-AP-资产类型']
                try:
                    # 尝试将其解析为 JSON 对象
                    if isinstance(asset_name, str):
                        asset_name = json.loads(asset_name)
                except json.JSONDecodeError:
                    # 若解析失败，说明不是 JSON 格式，保持原样
                    pass
                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
                if i['ext']['BPO标注-AP-资产型号'] == "设备":
                    hardtype = 1
                elif  i['ext']['BPO标注-AP-资产型号'] == "配件" :
                    hardtype = 2
                res = GetBestMatchItemonline_old(key,hardtype,clientinfo)
        else:
            res = ""
        infoout = do_waterlevellineres_listassetspu(res, info,hardtype)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list


def do_waterlevelline_autotest_aseetspu_pre(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
        info['exp'] = [
            {'label': i['ext']['BPO标注-AP-资产型号'], 'score': score_threshold},
            {'label': i['ext'].get('BPO标注-AP-资产型号1', ''), 'score': score_threshold}]
        info['artificial'] = info['exp']
        info['label']=[]
        if i['ext']['BPO标注-AP-资产名称']:
            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
                asset_name = i['ext']['BPO标注-AP-资产名称']
                asset_name = i['ext']['BPO标注-AP-资产类型']
                try:
                    # 尝试将其解析为 JSON 对象
                    if isinstance(asset_name, str):
                        asset_name = json.loads(asset_name)
                except json.JSONDecodeError:
                    # 若解析失败，说明不是 JSON 格式，保持原样
                    pass
                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
                if i['ext']['BPO标注-AP-资产型号'] == "设备":
                    hardtype = 1
                elif  i['ext']['BPO标注-AP-资产型号'] == "配件" :
                    hardtype = 2
                res = test_hardware_match(key,hardtype,clientinfo)
        else:
            res = ""
        infoout = do_waterlevellineres_listassetspu_pre(res, info,hardtype)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list

def do_waterlevelline_autotest_search(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext']['BPO标注-AP-资产名称']
        info['output']['用户输入/output'] = i['ext']['BPO标注-AP-资产名称']
        info['exp'] = [
            {'label': i['ext']['BPO标注-AP-资产型号'], 'score': score_threshold},
            {'label': i['ext'].get('BPO标注-AP-资产型号1', ''), 'score': score_threshold}]
        info['artificial'] = info['exp']
        info['label']=[]
        if i['ext']['BPO标注-AP-资产名称']:
            if "设备" in i['ext']['BPO标注-AP-分发技能'] or "配件" in i['ext']['BPO标注-AP-分发技能']:
                asset_name = i['ext']['BPO标注-AP-资产名称']
                asset_name = i['ext']['BPO标注-AP-资产类型']
                try:
                    # 尝试将其解析为 JSON 对象
                    if isinstance(asset_name, str):
                        asset_name = json.loads(asset_name)
                except json.JSONDecodeError:
                    # 若解析失败，说明不是 JSON 格式，保持原样
                    pass
                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
                if i['ext']['BPO标注-AP-资产型号'] == "设备":
                    hardtype = 1
                elif  i['ext']['BPO标注-AP-资产型号'] == "配件" :
                    hardtype = 2
                res = searchListAssetModelScope(key,hardtype,clientinfo)
        else:
            res = ""
        infoout = do_waterlevellineres_sr(res, info,hardtype)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list


def do_waterlevelline_autotest_SoftwareApplyRecommendList(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "实际输出/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext'].get('BPO标注-AP-资产名称') or i['ext'].get('BPO标注-AP-资产名称')
        info['output']['实际输出/output'] = i['ext']['BPO标注-AP-资产名称']
        info['exp'] = []
        for j in [i['ext']['BPO标注-AP-资产型号'], i['ext'].get('BPO标注-AP-资产型号1'),
                  i['ext'].get('BPO标注-AP-资产型号2'), i['ext'].get('BPO标注-AP-资产型号3'),
                  i['ext'].get('BPO标注-AP-资产型号4'), i['ext'].get('BPO标注-AP-资产型号5'),
                  i['ext'].get('BPO标注-AP-资产型号6'), i['ext'].get('BPO标注-AP-资产型号7'),
                  i['ext'].get('BPO标注-AP-资产型号8'), i['ext'].get('BPO标注-AP-资产型号9'),
                  i['ext'].get('BPO标注-AP-资产型号10')]:
            if j:
                info['exp'].append({'label': j, 'score': score_threshold})
            if info['exp'] == '':
                break
        info['artificial'] = info['exp']
        info['label']=[]
        if i['ext']['BPO标注-AP-资产名称']:
            if "软件" in i['ext']['BPO标注-AP-分发技能']:
                asset_name = i['ext']['BPO标注-AP-资产名称']
                try:
                    # 尝试将其解析为 JSON 对象
                    if isinstance(asset_name, str):
                        asset_name = json.loads(asset_name)
                except json.JSONDecodeError:
                    # 若解析失败，说明不是 JSON 格式，保持原样
                    pass
                key = asset_name.get('asset_name') if isinstance(asset_name, dict) else asset_name
                res = SoftwareApplyGetBestMatchItem(key,clientinfo)
        else:
            res = ""
        infoout = do_waterlevellineres_software(res, info)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list


def do_waterlevellineres_software(res, info):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}]
        info['rt'] = False
        return info
    if res["data"].get("SoftwareApplyRecommendList") == None:
        info['label'] = [{'label': '', 'score': 0},{'label': '', 'score': 0.8}]
        info['rt'] = False
        if info['exp'][0]['label']=='':
            info['rt'] = True
        return info
    reslist=res["data"]["SoftwareApplyRecommendList"]
    aaa ={}
    info['output']['实际输出/output'] = 'requestId:'+res.get('requestId')
    # 判断res["body"]["Results"]不为空，空则：label0 label1 为空，label默认2级
    if reslist:
        # 取["Results"]下前2个结果，若只有1个结果，label1为空
        if len(reslist) > 0:
           for j in range(len(reslist)):
               aaa = {'label': reslist[j]['Data']['Name']['ValueZh'],
                      'score': reslist[j]['Score']}
               info['label'].append(copy.deepcopy(aaa))

        info['rt'] = do_businessassertionrules(info['label'],info['exp'])
    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
    return info

def do_businessassertionrules(label, epx):
    """
    业务断言
    :param res:
    :param info:
    :return:
    """
    # 当预期值或实际值列表为空时，直接返回 False
    if not epx or not label:
        return False

    # 规则1：当预期值为1维时
    if len(epx) == 1:
        return epx[0]['label'] == label[0]['label']

    # 规则2：当预期值大于等于 实际值时，判断预期值包含实际值
    if len(epx) >= len(label):
        for i in range(len(label)):
            if epx[i]['label'] != label[i]['label']:
                return False
        return True

    # 规则3：当预期值小于 实际值时，判断实际值包含预期值
    for i in range(len(epx)):
        if epx[i]['label'] != label[i]['label']:
            return False
    return True






def get_conversationlogs1(startAt):
    """
    对话ID 技能分发 用户输入
    res_data = {
            'intentID': 7485259579248705537,
            'skillLabels': ["GUI 设备/配件申请"],
            'userInput': "我要申请一个鼠标",

         }
         """
    data = webapiClient().get_intent_detail_list(startAt)


def get_conversationlogs(startAt, pageSize=10):
    """
    对话ID 技能分发 用户输入
    res_data = {
            'intentID': 7485259579248705537,
            'skillLabels': ["GUI 设备/配件申请"],
            'userInput': "我要申请一个鼠标",

         }
    """
    try:
        # 之前提到形参 'pageSize' 未填，这里假设默认值为 10，你可按需修改
        data = webapiClient().get_intent_detail_list(startAt, pageSize=10)
        return data
    except KeyError as ke:
        print(f"KeyError 发生: 数据中缺少必要的键，错误详情: {ke}")
        return None
    except IndexError as ie:
        print(f"IndexError 发生: 索引超出范围，错误详情: {ie}")
        return None
    except Exception as e:
        print(f"发生未知错误: {e}")
        return None


def write_reslut(data, Testsuitelink, title):
    """
    写入表格
    """
    try:
        # 解析 spreadsheet_token
        spreadsheet_token = Testsuitelink.split("/")[-1]

        # 生成新工作表名称
        new_sheet_title = f"{title}{datetime.datetime.now().strftime('%Y_%m_%d_%H_%M_%S')}"
        sheetinfo = {"index": 0, "title": new_sheet_title}

        # 创建新工作表
        spreadsheet0 = LarkdocsClient().createsheets(spreadsheet_token, sheetinfo)
        sheet_id = spreadsheet0['sheet_id']

        # 准备表头数据
        headers = list(data[0].keys())
        header_data = [
            {
                "range": f"{sheet_id}!{chr(ord('A') + col)}1:{chr(ord('A') + col)}1",
                "values": [[[{"text": {"text": header}, "type": "text"}]]]
            }
            for col, header in enumerate(headers)
        ]

        # 写入表头
        LarkdocsClient().writesheets(spreadsheet_token, sheet_id, {"value_ranges": header_data})

        # 写入数据
        for row, row_data in enumerate(data, start=1):
            row_values = [
                {
                    "range": f"{sheet_id}!{chr(ord('A') + col)}{row + 1}:{chr(ord('A') + col)}{row + 1}",
                    "values": [[[{"text": {"text": str(row_data[header])}, "type": "text"}]]]
                }
                for col, header in enumerate(headers)
            ]
            LarkdocsClient().writesheets(spreadsheet_token, sheet_id, {"value_ranges": row_values})

        return True
    except KeyError as ke:
        print(f"KeyError 发生: 数据中缺少必要的键，错误详情: {ke}")
        return False
    except IndexError as ie:
        print(f"IndexError 发生: 索引超出范围，错误详情: {ie}")
        return False
    except Exception as e:
        print(f"发生未知错误: {e}")
        return False


def write_excletolist(data_name):
    """
    1. 读取本地表格
    2. 将表格内容拼接为text
    """
    try:
        # 查看当前工作目录
        print(f"当前工作目录: {os.getcwd()}")
        # /Users/bytedance/itam_assistant/itam_assistant/accessory.csv
        # 构建文件路径
        file_path = f'data/{data_name}.csv'
        Candidates = []
        Candidate = {
            "Score": 0,
            "Text": "IOS手机",
            "Attrs": {"id": "", "type": ""}}
        text = ""
        with open(file_path, 'r', encoding='utf-8', newline='') as file:
            reader = csv.reader(file)
            headers = next(reader)  # 读取表头
            for header in headers:
                text += f"{header}: "
            text = text.rstrip(': ') + '\n'

            for row in reader:
                textout = ""
                textout += ', '.join(row)
                Candidate['Text'] = textout
                Candidates.append(copy.deepcopy(Candidate))
        return Candidates
    except FileNotFoundError:
        print(f"未找到文件: {file_path}")
        return None
    except Exception as e:
        print(f"发生未知错误: {e}")
        return None



def do_waterlevelline_autotest_fix(collections, clientinfo, score_threshold):
    """
    水位线评测- 返回 符合报告模式的结果
    """
    keywprd= []
    info_list = []
    info = {
        "input": {
            "用户输入/userInput": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "output": {
            "用户输入/output": "我要申请软件，名字叫：ai_xzh_all_restricted_software完全受限软件"
        },
        "rt": True,
        "label": [{"label": "GUI 软件申请", "score": 0.6}, {"label": "软件申请", "score": 0.5}],
        "exp": [{"label": "GUI 软件申请", " score": 0.9}, {"label": "软件申请", "score": 0.8
                                                       }],
        "artificial": []
    }
    a =0
    for i in collections:
        info['input']['用户输入/userInput'] = i['ext']['资产名称']
        info['output']['用户输入/output'] = i['ext']['资产名称']
        info['exp'] = []
        for j in [i['ext']['匹配型号1'], i['ext'].get('匹配型号2'),i['ext'].get('匹配型号3'),i['ext'].get('匹配型号4'),i['ext'].get('匹配型号5'),i['ext'].get('匹配型号6'),i['ext'].get('匹配型号7'),i['ext'].get('匹配型号8'),i['ext'].get('匹配型号9'),i['ext'].get('匹配型号10')]:
            if j:
                info['exp'].append({'label': j, 'score': score_threshold})
        #判断i['ext']['BPO标注-AP-资产型号']是否为空，为空就不用读取，不为空就读取
        if i['ext']['资产名称']:
            asset_name = i['ext']['资产名称']
            try:
                if isinstance(asset_name, str):
                    asset_name = json.loads(asset_name)
            except json.JSONDecodeError:
                # 若解析失败，说明不是 JSON 格式，保持原样
                pass
        info['artificial'] = info['exp']
        if i['ext']['资产名称']:
            asset_name = i['ext']['资产名称']
            try:
                if isinstance(asset_name, str):
                    asset_name = json.loads(asset_name)
            except json.JSONDecodeError:
                # 若解析失败，说明不是 JSON 格式，保持原样
                pass
            if "设备领用" in i['ext']['评测集标签']:
                keywprd = GetBestMatchItemandres_new(asset_name, i['ext']['资产类型'], clientinfo)

        else:
            res = ""
        infoout = do_waterlevellineres_listv3(keywprd, info)
        info_list.append(copy.deepcopy(infoout))
        a = a+1
        print("这是"+str(a))
        bbb = a
    return info_list


def do_waterlevellineres_listv3(res, info):
    """
    获取结果，并组装水位线info
    """
    if res == '':
        info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False
        return info
    reslist = res['res']
    info['output']['用户输入/output'] = 'log_id:' + res.get('log')
    if reslist:
        #取所有结果并追加到info['label']
        info['label'] = []
        if len(reslist) > 0:
            for j in range(len(reslist)):
                aaa = {'label': reslist[j]['Name'],
                       'score': reslist[j]['Score']}
                info['label'].append(copy.deepcopy(aaa))
        # 判断exp和label是否一致，一致则：rt=True，不一致则：rt=False
        for a in range(len(info['exp'])):
            if info['exp'][a]['label']== info['label'][a]['label']:
                info['rt'] = True
            else:
                info['rt'] = False
                break
    else:
        info['label'] = info['label'] = [{'label': '', 'score': 0}, {'label': '', 'score': 0}]
        info['rt'] = False

    return info


# -*- coding: utf-8 -*-
#初始化 表单数据

Clientin = {
    "aily_app_id": "spring_f17d05d924__c",
    "app_id": "cli_a6e3aea1a13c900c",
    "app_secret": "J0fAPt3BL6bv4KUJV0dJMdTUdr0pv3xx",
    "cookie": "X-Kunlun-SessionId=L%3A3b34958803f34f43a52c.eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ2YWwiOnsidGVuYW50X2lkIjozOTAsInVzZXJfaWQiOjE3MjIxNjYwNzMxOTk2NDUsInRlbmFudF9kb21haW5fbmFtZSI6ImFwYWFzIiwic2Vzc2lvbl92ZXJzaW9uIjoidjIwMjAtMDUtMTkiLCJ3c190b2tlbiI6Ilc6OTk3Y2MwNTA3OTRlNGFmYWFkYzEiLCJsb2dpbl90b2tlbiI6IjE3MDE3ZmFlMWJlNjVlMzdzSzBhMzA0ZjY0N2MyZmFjY2QwSjRFYmNmNGVjNzAzZDgwOWYxNDVnNDY0MzY1ZjEyNWI0YmZlZDhhTmMiLCJzb3VyY2VfY2hhbm5lbCI6ImZlaXNodSIsInRlbmFudF9rZXkiOiI3MzY1ODhjOTI2MGYxNzVkIiwiZXh0ZXJuYWxfZG9tYWluX25hbWUiOiJieXRlZGFuY2UiLCJvcmlnaW5hbF90ZW5hbnRfaWQiOjAsIm9yaWdpbmFsX3VzZXJfaWQiOjAsImlkcF9jaGFubmVsIjoiIn0sImV4cCI6MTc1ODk0MTY3MH0.l9yn5zbWFhOEJml5iA69TpFwZ7qgLMzj7L0cj4Ryozc; passport_web_did=7487801556726579201; passport_trace_id=7487801556748156956; QXV0aHpDb250ZXh0=2f506053fdd544e7aa0df84c66a287f9; locale=zh-CN; landing_url=https://accounts.feishu.cn/accounts/page/login?app_id=107&no_trap=1&redirect_uri=https%3A%2F%2Fapaas.feishu.cn%2Fai%2Fspring_f17d05d924__c%2Fmanagement%2Fchat-log; _gcl_au=1.1.1249684330.1743389657; s_v_web_id=verify_m8wh6ssk_JRUTLUkb_AJsu_4Xjm_ANzV_gLPDip941iqw; __tea__ug__uid=7487801495396992562; _ga=GA1.2.1834362348.1743389657; _gid=GA1.2.758422620.1743389658; session=XN0YXJ0-4e7g6c2c-da65-4492-a6f6-6413002bd949-WVuZA; session_list=XN0YXJ0-4e7g6c2c-da65-4492-a6f6-6413002bd949-WVuZA; login_recently=1; _ga_VPYRHN104D=GS1.1.1743389657.1.1.1743389669.48.0.0; msToken=4W_kQaUJyB5jBl5FX8vjfY6SYAFcNAp7NiDqM3-QyBN0XIF24a5SyaOeTpfzIZAuNfH-cGjXK1u3tNXV3ETo8Z2ZTQFLGSTFF2KmMr35XQsODVrddz8FdHAfyJg4F7ayxiDsicO5ObKgK0Y_95Bq1d12vKKbJ99vm9IZWEpcRFLG; kunlun-session-v2=L%3A3b34958803f34f43a52c.eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ2YWwiOnsidGVuYW50X2lkIjozOTAsInVzZXJfaWQiOjE3MjIxNjYwNzMxOTk2NDUsInRlbmFudF9kb21haW5fbmFtZSI6ImFwYWFzIiwic2Vzc2lvbl92ZXJzaW9uIjoidjIwMjAtMDUtMTkiLCJ3c190b2tlbiI6Ilc6OTk3Y2MwNTA3OTRlNGFmYWFkYzEiLCJsb2dpbl90b2tlbiI6IjE3MDE3ZmFlMWJlNjVlMzdzSzBhMzA0ZjY0N2MyZmFjY2QwSjRFYmNmNGVjNzAzZDgwOWYxNDVnNDY0MzY1ZjEyNWI0YmZlZDhhTmMiLCJzb3VyY2VfY2hhbm5lbCI6ImZlaXNodSIsInRlbmFudF9rZXkiOiI3MzY1ODhjOTI2MGYxNzVkIiwiZXh0ZXJuYWxfZG9tYWluX25hbWUiOiJieXRlZGFuY2UiLCJvcmlnaW5hbF90ZW5hbnRfaWQiOjAsIm9yaWdpbmFsX3VzZXJfaWQiOjAsImlkcF9jaGFubmVsIjoiIn0sImV4cCI6MTc1ODk0MTY3MH0.l9yn5zbWFhOEJml5iA69TpFwZ7qgLMzj7L0cj4Ryozc; kunlun-session-token=2b32fc3c28f44fb89bab94ad072a05c9f2f844c49705c95d76bae40479a189b7; _tea_utm_cache_1229=undefined; sl_session=eyJhbGciOiJFUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NDM0MzI4NzEsInVuaXQiOiJldV9uYyIsInJhdyI6eyJtZXRhIjoiQVdIazBuRzhRUUFDQUFBQUFBQUFBQUZuNmdQWUFVNEFBV2ZxQTlnQlRnQUJaK29ENWRES3dBSUNLZ0VBUVVGQlFVRkJRVUZCUVVKdU5tZFFiRE40ZDBGQlp6MDkiLCJzdW0iOiJlMmM4YTIwMTcyMDcxNmVjYTFiOWRlOTQ5Yjc3OGJkNDczOGIzOTAwNWJiNTJhYTkyOTM2YTRhZWIzMGI2ZTY0IiwibG9jIjoiemhfY24iLCJhcGMiOiJSZWxlYXNlIiwiaWF0IjoxNzQzMzg5NjcxLCJzYWMiOnsiVXNlclN0YWZmU3RhdHVzIjoiMSIsIlVzZXJUeXBlIjoiNDIifSwibG9kIjpudWxsLCJjbmYiOnsiamt0IjoiYkx6aTdPRDBHS09mNllOQ0xGamtPZWtuQkNRSHM2ZFh5STdmcTVubE93VSJ9LCJucyI6ImxhcmsiLCJuc191aWQiOiI3MDUzOTk0MzAyMzAwNTUzMjE4IiwibnNfdGlkIjoiMSIsIm90IjozLCJjdCI6MTc0MzM4OTY3MCwicnQiOjE3NDMzODk2NzB9fQ.2pQlqU6fuqnw_iqtJe1sH1FfSSXBpFQ0RAoaRccxHEaHSBvqsdc9_7e4zjgcHOhTjISi3mGw3EC3EXftLj5Otw; passport_app_access_token=eyJhbGciOiJFUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NDM0MzI4NzIsInVuaXQiOiJldV9uYyIsInJhdyI6eyJtX2FjY2Vzc19pbmZvIjp7IjEwNyI6eyJpYXQiOjE3NDMzODk2NzIsImFjY2VzcyI6dHJ1ZX19LCJzdW0iOiJlMmM4YTIwMTcyMDcxNmVjYTFiOWRlOTQ5Yjc3OGJkNDczOGIzOTAwNWJiNTJhYTkyOTM2YTRhZWIzMGI2ZTY0In19.jtfbxALtDnZYTJx4cb6ohPy2uDVCHTuh0x-Dg7Ui1F4vMO3aka7rvOeZTIwGJ7IlAn0b-OjBOWQEVQvHthhEwQ; swp_csrf_token=a239a297-e0f7-4820-aa3a-6349c8a04977; t_beda37=10a0c227407070710f979ef9d5b530118d080fd0ec27f2c3ce04c251a5a20d70",
    "x-kunlun-token": "17017fae1be65e37sK0a304f647c2faccd0J4Ebcf4ec703d809f145g464365f125b4bfed8aNc",
    "x-tt-env": "ppe_cn_env_self_test_feat_cr_a",
    "Authorization": "Basic cm40cmFpdTRwenY1cGlsYTo2bWhvOXV3ZXFrOHZpbDllcXRxMHZ1YmVnc2xjeXBucg==",
}

class SingletonMeta(type):
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super().__call__(*args, **kwargs)
        return cls._instances[cls]

class Clientassign(metaclass=SingletonMeta):
    """
    定义一个全局变量 Client
    该类为单例类，确保整个应用中只有一个实例
    """
    def __init__(self, Clientinfox):

        self.aily_app_id = Clientinfox.get("data_set_ailyappid") or Clientin["aily_app_id"]
        self.app_id = Clientinfox.get("data_set_appid") or Clientin["app_id"]
        self.app_secret = Clientinfox.get("data_set_appsecret") or Clientin["app_secret"]
        self.cookie = Clientinfox.get("data_set_cookie") or Clientin["cookie"]
        self.x_kunlun_token = Clientinfox.get("data_set_kunluntoken") or Clientin["x-kunlun-token"]
        self.x_tt_env = Clientinfox.get("data_set_ppeenv") or Clientin["x-tt-env"]
        self.authorization = Clientinfox.get("data_set_auth") or Clientin["Authorization"]


if __name__ == '__main__':
    Clientinfox = {
        "data_set_ailyappid": "123",
        "data_set_appid": "456",
        "data_set_appsecret": "789",
        "data_set_cookie": "012",
        "data_set_kunluntoken": "345",
        "data_set_ppeenv": "678",
        "data_set_auth": "901",
    }
    b=Clientassign(Clientinfox)






# -*- coding: utf-8 -*-
import copy
import http.client
import json
import time
import requests
itamheaders = {
    'authorization': 'Bearer eyJhbGciOiJSUzI1NiIsImtpZCI6InYyIiwidHlwIjoiSldUIn0.eyJleHAiOjE3NDI1NDYyMTcsImp0aSI6ImJKMk9hV0dkanU5QStMMXciLCJpYXQiOjE3NDEyNTAyMTcsImlzcyI6InRhbm5hIiwic3ViIjoiMzgzMDMxOUBieXRlZGFuY2UucGVvcGxlIiwidGVuYW50X2lkIjoiYnl0ZWRhbmNlLnBlb3BsZSIsInRlbmFudF9uYW1lIjoiIiwicHJvamVjdF9rZXkiOiJjcm1TZmdIVmU1dXhIMHJyIiwidW5pdCI6ImV1X25jIiwiYXV0aF9ieSI6Mn0.eHghtX4NOnD1uD65bzqv7n1J3mtnPPXJoVKIWDwl4PMZPkqc3FisH4RMXxDqeOyDCgRHYhmam7VEenl8T0UIKpzI8ad8yMiZytvAkNhclLjCdmokLB7DdwnbO1qeDLxdqjL-S3da0KHHkOT8j-rWR94XJ0N7T_snoko4Ovsp13w',
    'Content-Type': 'application/json'

}



class webapiClient():
    def __init__(self, clientin):
        """
       初始化 Client 实例,tenant_access_token 会在 Client 初始化时自动获取
        """
        headers = {
            'cookie': clientin['cookie'],
            'x-kunlun-token': clientin['x-kunlun-token'],
            'Content-Type': "application/json"}
        self.headers = headers
        self.itamheaders = headers
        self.conn = http.client.HTTPSConnection("apaas.feishu.cn")

    def get_intent_detail_list(self, startAt, pageSize):
        """
        outdata:
            对话ID 技能分发 用户输入
           res_ = {
          'intentID': 7485259579248705537,
          'userInput': "我要申请一个鼠标",
          'skillLabels': ["GUI 设备/配件申请"],
           'apply_day':"",
          'apply_num':"",
          'asset_name':"",
          'device_type':""
           }
        """
        # 输入参数类型和范围检查
        if not isinstance(startAt, int) or startAt < 0:
            raise ValueError("startAt 必须是一个非负整数")
        if not isinstance(pageSize, int) or pageSize < 0:
            raise ValueError("pageSize 必须是一个非负整数")

        endAt = int(time.time()) or 1748361600
        payload = json.dumps({
            "startAt": startAt,
            "endAt": endAt,
            "matchIntentID": "",
            "matchStatus": [],
            "pageSize": pageSize + 1000
        })
        try:
            self.conn.request("POST","/ai/api/v1/conversational_runtime/namespaces/spring_f17d05d924__c/stats/intent_detail_list",payload, self.headers)
            res = self.conn.getresponse()
            # 检查响应状态码
            if res.status != 200:
                raise http.client.HTTPException(f"请求失败，状态码: {res.status}, 原因: {res.reason}")

            data = res.read()
            try:
                data = json.loads(data.decode("utf-8"))
            except json.JSONDecodeError:
                raise ValueError("无法将响应数据解析为 JSON 格式")

            # 检查响应数据结构
            if 'data' not in data or 'intentDetailList' not in data['data']:
                raise ValueError("响应数据缺少必要的字段 'data' 或 'intentDetailList'")

            res_list = []
            data_ = data['data']['intentDetailList']
            for i in data_:
                if i['channelType'] in ["LARK_OPEN_API"]:
                    res_list.append({
                        '对话日志/intentID': i['intentID'],
                        '用户输入/userInput': i['userInput'],
                        '数据是否有效/isdatavalid': "是",
                        '语言/language': "zh",
                        '是否 IT 问题/isITproblem': "是",
                        '业务场景/businessscenario': "NULL",
                        '分发技能/skill': i['skillLabels'],
                        '型号关键字词/asset_name': "NULL",
                        '型号类型/device_type': "NULL",
                        '匹配型号/AssetNamelist': "NULL",
                    })
            return res_list
        except http.client.HTTPException as http_err:
            print(f"HTTP 请求错误: {http_err}")
            return res_list
        except ValueError as value_err:
            print(f"值错误: {value_err}")
            return res_list
        except Exception as general_err:
            print(f"发生未知错误: {general_err}")
            return res_list

    def get_urlintentID(self, intentID):
        """
        输入：intentID
        输出：url
        """
        max_retries = 3
        retries = 0
        while retries < max_retries:
            try:
                payload = ''
                urlintentID = f'https://apaas.feishu.cn/ai/api/v1/conversational_runtime/namespaces/spring_f17d05d924__c/intent/{intentID}?pageSize=20&statusFilter=%5B%5D&fieldFilter=_node_id&fieldFilter=status&fieldFilter=usages&fieldFilter=_node_name&fieldFilter=_node_type&fieldFilter=title_for_maker&fieldFilter=associate_id'
                response = requests.request("GET", urlintentID, headers=self.headers, data=payload)
                # 检查响应状态码
                response.raise_for_status()
                response = response.json()
                # 检查特定错误状态码
                if 'status_code' in response and response['status_code'] == "k_gw_ec_100033":
                    retries += 1
                    if retries < max_retries:
                        print(f"接口不存在，正在进行第 {retries} 次重试...")
                        continue
                    else:
                        print(f"接口不存在，已达到最大重试次数 {max_retries} 次")
                        return None
                return response
            except (requests.RequestException, json.JSONDecodeError) as e:
                retries += 1
                if retries < max_retries:
                    print(f"请求失败，原因: {e}，正在进行第 {retries} 次重试...")
                else:
                    print(f"请求失败，已达到最大重试次数 {max_retries} 次，原因: {e}")
        return None

    def get_urlnodeid(self, intentID, nodeid):
        """
        输入：intentID
        输出：url
        """
        max_retries = 3
        retries = 0
        while retries < max_retries:
            try:
                payload = ''
                urlnodeid = f'https://apaas.feishu.cn/ai/api/v1/conversational_runtime/namespaces/spring_f17d05d924__c/association/{intentID}/node/{nodeid}?intentID={intentID}'
                response = requests.request("GET", urlnodeid, headers=self.headers, data=payload)
                # 检查响应状态码
                response.raise_for_status()
                response = response.json()
                # 检查特定错误状态码
                if 'status_code' in response and response['status_code'] == "k_gw_ec_100033":
                    retries += 1
                    if retries < max_retries:
                        print(f"接口不存在，正在进行第 {retries} 次重试...")
                        continue
                    else:
                        print(f"接口不存在，已达到最大重试次数 {max_retries} 次")
                        return None
                return response
            except (requests.RequestException, json.JSONDecodeError) as e:
                retries += 1
                if retries < max_retries:
                    print(f"请求失败，原因: {e}，正在进行第 {retries} 次重试...")
                else:
                    print(f"请求失败，已达到最大重试次数 {max_retries} 次，原因: {e}")
        return None



    def get_intent_detail_llm(self, res_list):
        """
        提取关键词：
        槽位提取：'apply_day': "",'apply_num': "",'asset_name': "",'device_type': ""
        表头字段：
        '对话日志/intentID': 7485264011232886786,
        '用户输入/userInput': "我要申请一个鼠标",
        '数据是否有效/isdatavalid': "是",
        '语言/language': "zh",
        '是否 IT 问题/isITproblem': "是",
        '业务场景/businessscenario': "NULL",
        '分发技能/skill': "NULL",
        '型号关键字词/asset_name': "NULL", #显示器
        '型号类型/device_type': "NULL",    # 设备 配件 软件
        '匹配型号/AssetNamelist': "NULL",
        """
        ii0 = []
        ii = {
            '对话日志/intentID': "7485264011232886786",
            '用户输入/userInput': "我要申请一个鼠标",
            '数据是否有效/isdatavalid': "是",
            '语言/language': "zh",
            '是否 IT 问题/isITproblem': "是",
            '业务场景/businessscenario': "NULL",
            '分发技能/skill': "NULL",
            'llm关键词': "NULL"
        }
        try:
            # 检查 res_list 是否为空
            if not res_list:
                print("输入的 res_list 为空")
                return []
            for i in res_list:
                print("urlintentID_1:" + str(i))
                ii['分发技能/skill'] = i['分发技能/skill']
                ii['对话日志/intentID'] = i['对话日志/intentID']
                ii['用户输入/userInput'] = i['用户输入/userInput']
                intentID = str(ii['对话日志/intentID'])
                res_ = self.get_urlintentID(intentID)
                if res_ is None:
                    continue
                response = res_
                for j in response['data']['steps']:
                    if j['titleForMaker'] in ["槽位抽取", "LLM 2", "LLM"]:
                        nodeid = j['nodeID']
                        data_nodeid = self.get_urlnodeid(intentID, nodeid)
                        if data_nodeid is None or 'data' not in data_nodeid or 'step' not in data_nodeid['data'] or 'output' not in data_nodeid['data']['step'] or data_nodeid['data']['step']['output'] == "":
                            ii['llm关键词'] = "NULL"
                        else:
                            ii['llm关键词'] = json.loads(data_nodeid['data']['step']['output'])['response']
                ii0.append(copy.deepcopy(ii))
            return ii0
        except requests.RequestException as req_err:
            print(f"请求错误: {req_err}")
            return ii0
        except Exception as general_err:
            print(f"发生未知错误: {general_err}")
            return ii0

    def get_bestmatchitemforreturn(self, keyword):
        """
        mock数据，获取最佳匹配的sku/spu
        mock数据：公用配件列表、设备列表、软件列表
        todo：mock数据表格为飞书文档或者其他？
        """
        _urlGetBestMatchItemForReturn = "https://asset-mig-pre.bytedance.net/aily/api/itservice/ai/GetBestMatchItemForReturn"

        payload = json.dumps({
            "SearchKey": keyword,
            "AiUseType": 1,
            "ListReturnableAccessoryRequest": {
                "IsAll": True,
                "Page": {
                    "PageNum": 1,
                    "PageSize": 30
                },
                "OwnerUserID": "",
                "AccessoryApplyTypeList": []
            },
            "GetAssetListRequest": {
                "Status": 6,
                "Search": "",
                "IsAll": True,
                "SubStatusList": [
                    12,
                    18,
                    19
                ],
                "Page": {
                    "PageNum": 1,
                    "PageSize": 30
                },
                "OrganizationalUnitID": 1
            }
        })
        response = requests.request("GET", _urlGetBestMatchItemForReturn, headers=self.headers, data=payload)
        response = json.loads(response.text)

    def get_segsearchcandidates(self, res_list):
        # 获取分数值
        ### 读取设备&配件的信息并拼接到text里面
        ### 遍历res_list中的device_name
        ###判断是否在asset.json里面
        ###调用算法接口获取设备&配件的分数值
        pass


""""""
if __name__ == '__main__':
    clientin = {
        'cookie': 'X-Kunlun-SessionId=L%3A028d306c70a340a69fe9.eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ2YWwiOnsidGVuYW50X2lkIjozOTAsInVzZXJfaWQiOjE3MjIxNjYwNzMxOTk2NDUsInRlbmFudF9kb21haW5fbmFtZSI6ImFwYWFzIiwic2Vzc2lvbl92ZXJzaW9uIjoidjIwMjAtMDUtMTkiLCJ3c190b2tlbiI6Ilc6ZTU3MmJlYzNmOGIzNDE0ZDk0NDYiLCJsb2dpbl90b2tlbiI6IjE3MDE3ZmFlMWJlNjVlMzc2V1VhMzA0ZjY0N2MyZmFjY2QwZ256YmNmNGVjNzAzZDgwOWYxNHJPWTY0MzY1ZjEyNWI0YmZlZDhreUciLCJzb3VyY2VfY2hhbm5lbCI6ImZlaXNodSIsInRlbmFudF9rZXkiOiI3MzY1ODhjOTI2MGYxNzVkIiwiZXh0ZXJuYWxfZG9tYWluX25hbWUiOiJieXRlZGFuY2UiLCJvcmlnaW5hbF90ZW5hbnRfaWQiOjAsIm9yaWdpbmFsX3VzZXJfaWQiOjAsImlkcF9jaGFubmVsIjoiIn0sImV4cCI6MTc2Mzg4MzY0NX0.VWyqct9gPOSXiX_72IqCRAknHsJK1aaZLIZ4gICbH5U; gd_random=eyJwZXJjZW50IjowLjY4NTgwODU2NDE4ODc2MjcsIm1hdGNoIjpmYWxzZX0=.iBiK3be8U+wA12/YghnWQbmDRz/vrBS/OQJpAvYx4XY=; trust_browser_id=3686a9b0-ce48-4e07-a0ce-e6928dc2bd6a; X-Kunlun-LoginTag=feishu; passport_trace_id=7389204030662426627; passport_web_did=7424353640858812419; QXV0aHpDb250ZXh0=9bcf0657fb6e47d497625011ffcd73e7; lark_sso_session=XN0YXJ0-488md350-54b2-433e-9eeb-b7a5c700ea26-WVuZA; X-Larkgw-Web-DID=3439857258174095984; X-Larkgw-Use-Lark-Session-119=1; __tea__ug__uid=7441424216023565850; is_anonymous_session=; fid=24c45ffc-f3d7-44f2-87ed-421f54ee78fb; lang=zh; i18n_locale=zh; locale=zh-CN; _gcl_au=1.1.2073766041.1742190427; _uetvid=44545540063311f08ed91353a6123699; _ga_7PY069DX7K=GS1.1.1742549605.1.0.1742549605.60.0.0; s_v_web_id=verify_m8cn771e_wyNgDZJ9_u4vt_4Tcr_8GHG_aoFTRqp3UEgK; _csrf_token=8d1282b097e1c2e7aea50829b47ffb77a72db55f-1745993230; help_center_session=7b5fca25-c6c5-4106-9d93-8709981a6957; _uuid_hera_ab_path_1=7502360423243071516; Hm_lvt_a79616d9322d81f12a92402ac6ae32ea=1746779408; apaas_web_did=1832530807807051; _tea_utm_cache_1229=undefined; lgw_csrf_token=c540cf747b5b41c2f749a2e1c0bd0900c3eb71b2-1747901330; _ga=GA1.2.113646166.1700115833; _gid=GA1.2.1661485038.1748331634; landing_url=https://accounts.feishu.cn/accounts/page/login?app_id=107&no_trap=1&redirect_uri=https%3A%2F%2Fapaas.feishu.cn%2Fai%2Fspring_f17d05d924__c%2Fmanagement%2Fchat-log; session=XN0YXJ0-583sf83f-7ceb-44bc-8578-0692b8383b7c-WVuZA; session_list=XN0YXJ0-583sf83f-7ceb-44bc-8578-0692b8383b7c-WVuZA; _ga_VPYRHN104D=GS2.1.s1748331633$o2$g1$t1748331645$j48$l0$h0; kunlun-session-v2=L%3A028d306c70a340a69fe9.eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ2YWwiOnsidGVuYW50X2lkIjozOTAsInVzZXJfaWQiOjE3MjIxNjYwNzMxOTk2NDUsInRlbmFudF9kb21haW5fbmFtZSI6ImFwYWFzIiwic2Vzc2lvbl92ZXJzaW9uIjoidjIwMjAtMDUtMTkiLCJ3c190b2tlbiI6Ilc6ZTU3MmJlYzNmOGIzNDE0ZDk0NDYiLCJsb2dpbl90b2tlbiI6IjE3MDE3ZmFlMWJlNjVlMzc2V1VhMzA0ZjY0N2MyZmFjY2QwZ256YmNmNGVjNzAzZDgwOWYxNHJPWTY0MzY1ZjEyNWI0YmZlZDhreUciLCJzb3VyY2VfY2hhbm5lbCI6ImZlaXNodSIsInRlbmFudF9rZXkiOiI3MzY1ODhjOTI2MGYxNzVkIiwiZXh0ZXJuYWxfZG9tYWluX25hbWUiOiJieXRlZGFuY2UiLCJvcmlnaW5hbF90ZW5hbnRfaWQiOjAsIm9yaWdpbmFsX3VzZXJfaWQiOjAsImlkcF9jaGFubmVsIjoiIn0sImV4cCI6MTc2Mzg4MzY0NX0.VWyqct9gPOSXiX_72IqCRAknHsJK1aaZLIZ4gICbH5U; kunlun-session-token=e337d885c13162ff663d9a991e6eb54f7dd3e04e539c8b817a923e225a87d3aa; msToken=su30ijthwqpaGKP8qOkL3viO1aXYouV3yjJ_EXTKoIlvgSJva8VvCSVRhhd1kKUHF6qdrLnsH6MF28bg8N3V1WVMmSA1ccqF8tPmt6YL0jVYhI6SePZBvIS6MJE2xkWY7vSYBCMoNax8pj4oITBwrtP_rG6yt25SlSFDdzu9WwYL; passport_app_access_token=eyJhbGciOiJFUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NDg0MDA5NTYsInVuaXQiOiJldV9uYyIsInJhdyI6eyJtX2FjY2Vzc19pbmZvIjp7IjEwNyI6eyJpYXQiOjE3NDgzNTc3NTYsImFjY2VzcyI6dHJ1ZX19LCJzdW0iOiI3NmY5MmYyNDQ4MDczNjc1MTA3NmI5ZTgyYzYyZWJmN2M3NzE0ZWVlOTM3YTg1NDUzZjhmNzc4NjEzYzY2NTBjIn19.qCGZwBOJ0tpGfLjtnncUTmLEai6u4D5me5ga-N8Tter0Ey5L6do2FPxoOacqLj1Wj2hxyHSTfad60hSsMTkPaQ; sl_session=eyJhbGciOiJFUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NDg0MDM1NTQsInVuaXQiOiJldV9uYyIsInJhdyI6eyJtZXRhIjoiQVdIazBuRzhRUUFDQUFBQUFBQUFBQUZuQ0pwTTZrU0FBMmNJbWt6cVJJQURaeklSUnZpQUFBRUNLZ0VBUVVGQlFVRkJRVUZCUVVKdlRsZDRPVTVvU2tGQlp6MDkiLCJzdW0iOiI3NmY5MmYyNDQ4MDczNjc1MTA3NmI5ZTgyYzYyZWJmN2M3NzE0ZWVlOTM3YTg1NDUzZjhmNzc4NjEzYzY2NTBjIiwibG9jIjoiemhfY24iLCJhcGMiOiJSZWxlYXNlIiwiaWF0IjoxNzQ4MzYwMzU0LCJzYWMiOnsiVXNlclN0YWZmU3RhdHVzIjoiMSIsIlVzZXJUeXBlIjoiNDIifSwibG9kIjpudWxsLCJjbmYiOnsiamt0IjoiRWtuRFMyTmdZVDR4Y2xZRDM4UU9KUHNkUFptLVluRHRaR3ZmX1hfSTJxTSJ9LCJucyI6ImxhcmsiLCJuc191aWQiOiI3MDUzOTk0MzAyMzAwNTUzMjE4IiwibnNfdGlkIjoiMSIsIm90IjozLCJjdCI6MTc0ODMzMTY0NSwicnQiOjE3NDgzMzE2NDV9fQ.BP9Q4Wxdq_TWB898FxFr4TlpqUN8-N1QC6fFWO57C8wiNeAcFNUfed8mGdd7kvBgbC5PjwnNJjoL0iXySUpuXQ; swp_csrf_token=dd289ebe-0ce4-42d2-aece-263b6abf2d45; t_beda37=e1445dd5c8a191cc38f34d9809eb3c5179904df5285bb079d87b96baad8ee3e5',
        "x-kunlun-token": "17017fae1be65e376WUa304f647c2faccd0gnzbcf4ec703d809f14rOY64365f125b4bfed8kyG"

    }
    startAt = 1748410380
    num = 1230
    res_list = webapiClient(clientin).get_intent_detail_list(1748410380,10)
    a = webapiClient(clientin).get_intent_detail_llm(res_list)







import json

import lark_oapi as lark
from lark_oapi.api.sheets.v3 import *


# SDK 使用说明: https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/server-side-sdk/python--sdk/preparations-before-development
# 以下示例代码默认根据文档示例值填充，如果存在代码问题，请在 API 调试台填上相关必要参数后再复制代码使用

class LarkdocsClient:
    def __init__(self):
        """
        初始化 Client 实例,tenant_access_token 会在 Client 初始化时自动获取
        https://github.com/larksuite/oapi-sdk-python
        """
        self.app_id = "cli_a48be9fd54a5900d"
        self.app_secret = "pfiNeWKbkfbRvUunX3TrKdCCnftlUbxl"
        # 创建 Lark 客户端
        self.lark_client = lark.Client.builder().app_id(self.app_id).app_secret(self.app_secret).build()

    def get_the_worksheet(self, spreadsheet_token):

        # 获取工作表
        # 创建client
        # 使用 user_access_token 需开启 token 配置, 并在 request_option 中配置 token
        # 构造请求对象
        try:
            request: QuerySpreadsheetSheetRequest = QuerySpreadsheetSheetRequest.builder() \
                .spreadsheet_token(spreadsheet_token) \
                .build()

            # 发起请求
            # option = self.lark_client.RequestOption.builder().user_access_token(
            # "u-hQ.Vthwt5blbznh92YFKhflkkfsAl5R3hW20l5cy07ag").build()
            response: QuerySpreadsheetSheetResponse = self.lark_client.sheets.v3.spreadsheet_sheet.query(request)

            # 处理失败返回
            if not response.success():
                lark.logger.error(
                    f"client.sheets.v3.spreadsheet_sheet.query failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
                return
            return response.data
            # 处理业务结果
            lark.logger.info(lark.JSON.marshal(response.data, indent=4))
        except Exception as e:
            lark.logger.error(f"[lark]get user id by email failed, err: {e}")
            return None, e

    def get_plaintextcontent(self, ranges, spreadsheet_token, sheet_id):
        # 创建client
        # 使用 user_access_token 需开启 token 配置, 并在 request_option 中配置 token
        # 构造请求对象
        # 构造请求对象
        # json_str = "{\"ranges\":[\"459f7e!A1:A1\"]}"
        body = ranges
        request: lark.BaseRequest = lark.BaseRequest.builder() \
            .http_method(lark.HttpMethod.POST) \
            .uri(f"/open-apis/sheets/v3/spreadsheets/{spreadsheet_token}/sheets/{str(sheet_id)}/values/batch_get_plain") \
            .token_types({lark.AccessTokenType.TENANT}) \
            .body(body) \
            .build()

        # 发起请求
        response: lark.BaseResponse = self.lark_client.request(request)

        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.request failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return

        # 处理业务结果
        lark.logger.info(str(response.raw.content, lark.UTF_8))
        return str(response.raw.content, lark.UTF_8)


    def createsheets(self, spreadsheet_token, title):
        # 创建工作表
        # json_str = "{\"index\":0,\"title\":\"abc\"}"
        # 构造请求对象
        body = title
        request: lark.BaseRequest = lark.BaseRequest.builder() \
            .http_method(lark.HttpMethod.POST) \
            .uri(f"/open-apis/sheets/v3/spreadsheets/{spreadsheet_token}/sheets") \
            .token_types({lark.AccessTokenType.TENANT}) \
            .body(body) \
            .build()

        # 发起请求
        response: lark.BaseResponse = self.lark_client.request(request)

        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.request failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return

        # 处理业务结果
        lark.logger.info(str(response.raw.content, lark.UTF_8))
        return json.loads(response.raw.content)['data']['sheet']


    def writesheets(self, spreadsheet_token, sheet_id, data):
        # 创建client
        # 使用 user_access_token 需开启 token 配置, 并在 request_option 中配置 token
        # 构造请求对象
        # 构造请求对象
        json_str = "{\"value_ranges\":[{\"range\":\"HEJb8z!C1:C1\",\"values\":[[[{\"text\":{\"text\":\"abc\"},\"type\":\"text\"}]]]}]}"
        body = json.loads(json_str)
        body = data
        request: lark.BaseRequest = lark.BaseRequest.builder() \
            .http_method(lark.HttpMethod.POST) \
            .uri(
            f"/open-apis/sheets/v3/spreadsheets/{spreadsheet_token}/sheets/{sheet_id}/values/batch_update?user_id_type=open_id") \
            .token_types({lark.AccessTokenType.TENANT}) \
            .body(body) \
            .build()

        # 发起请求
        response: lark.BaseResponse = self.lark_client.request(request)

        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.request failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return

        # 处理业务结果
        lark.logger.info(str(response.raw.content, lark.UTF_8))


if __name__ == '__main__':
    spreadsheet_token = ""
    sheets = LarkdocsClient().get_the_worksheet(spreadsheet_token)
    for i in sheets.sheets:

        column_count = i.grid_properties.column_count
        row_count = i.grid_properties.row_count
        sheet_id = i.sheet_id
        title = i.title

        #print(column_count, row_count, sheet_id, title)
        json_str = {"ranges": ["459f7e!A1:A1"]}
        json_str = {"ranges": [sheet_id + "!A1:A" + str(row_count)]}
        test = LarkdocsClient().get_plaintextcontent(json_str, spreadsheet_token, sheet_id)
        test = json.loads(test)
        userinput = test['data']['value_ranges'][0]['values']
        print(f"表头为{userinput[0]}")
        i = 0
        for i in range(1,row_count):
            if userinput[i][0]:
                print(userinput[i][0])
            else:
                break








from setuptools import setup, find_packages

setup(
    name="itam_assistant",  # 包名称
    version="0.1.11",    # 版本号
    author="liujunmeiD",
    author_email="1105030421@qq.com",
    description="优化版本--技能分发的结果展示-新增时间控制 14s",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/liujunmeiD/itam_assistant",
    packages=find_packages(),  # 自动发现所有包
    install_requires=[         # 依赖项
        "requests>=2.25.1",
        "numpy>=1.20.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",   # Python版本要求
)


import json

import lark_oapi as lark
from lark_oapi.api.auth.v3 import *
from lark_oapi.api.aily.v1 import *


# SDK 使用说明: https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/server-side-sdk/python--sdk/preparations-before-development
# 以下示例代码默认根据文档示例值填充，如果存在代码问题，请在 API 调试台填上相关必要参数后再复制代码使用
# 复制该 Demo 后, 需要将 "YOUR_APP_ID", "YOUR_APP_SECRET" 替换为自己应用的 APP_ID, APP_SECRET.

pre =['spring_f17d05d924__c']


class AilyLarkClient():
    def __init__(self,clientinfo):
        """
        初始化 Client 实例,tenant_access_token 会在 Client 初始化时自动获取
        """
        self.aily_app_id = clientinfo.get("aily_app_id") or "spring_f17d05d924__c"
        self.app_id = clientinfo.get("app_id") or "cli_a6e3aea1a13c900c"
        self.app_secret = clientinfo.get("app_secret") or "J0fAPt3BL6bv4KUJV0dJMdTUdr0pv3xx"
        # 创建 Lark-tenant tenant客户端
        self.tlark_client = lark.Client.builder().app_id(self.app_id).app_secret(self.app_secret).build()

        # 创建 Lark-tenant user 客户端
        self.ulark_client = lark.Client.builder().enable_set_token(True).log_level(lark.LogLevel.DEBUG).build()

    def get_tenant_access_token(self):
        # 构造请求对象
        request: InternalTenantAccessTokenRequest = InternalTenantAccessTokenRequest.builder() \
            .request_body(InternalTenantAccessTokenRequestBody.builder()
                          .app_id(self.app_id)
                          .app_secret(self.app_secret)
                          .build()) \
            .build()

        # 发起请求
        response: InternalTenantAccessTokenResponse = self.tlark_client.auth.v3.tenant_access_token.internal(request)

        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.auth.v3.tenant_access_token.internal failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return
        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.raw, indent=4))
        tenant_access_token = json.loads(response.raw.content).get("tenant_access_token")
        if tenant_access_token:
            return tenant_access_token
        else:
            lark.logger.error(
                f"client.auth.v3.tenant_access_token.internal failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return

    def create_ailysession(self, access_token):
        # 创建会话
        # 构造请求对象
        request: CreateAilySessionRequest = CreateAilySessionRequest.builder() \
            .request_body(CreateAilySessionRequestBody.builder()
                          .channel_context("{}")
                          .metadata("{}")
                          .build()) \
            .build()

        # 发起请求
        option = lark.RequestOption.builder().user_access_token(access_token).build()
        response: CreateAilySessionResponse = self.ulark_client.aily.v1.aily_session.create(request, option)

        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.aily.v1.aily_session.create failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return

        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.data, indent=4))
        return response.data.session.id

    def create_ailysessionaily_message(self, access_token, session_id, content):
        # 发送智能伙伴消息
        # 构造请求对象
        request: CreateAilySessionAilyMessageRequest = CreateAilySessionAilyMessageRequest.builder() \
            .aily_session_id(session_id) \
            .request_body(CreateAilySessionAilyMessageRequestBody.builder()
                          .content(content)
                          .content_type("MDX")
                          .idempotent_id("idempotent_id_1")
                          .build()) \
            .build()
        # 发起请求
        option = lark.RequestOption.builder().user_access_token(access_token).build()
        response: CreateAilySessionAilyMessageResponse = self.ulark_client.aily.v1.aily_session_aily_message.create(
            request,
            option)
        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.aily.v1.aily_session_aily_message.create failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return
        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.data, indent=4))
        return response.data.message.id

    def create_ailysession_run(self, access_token, aily_session_id):
        # 创建运行
        # 构造请求对象
        request: CreateAilySessionRunRequest = CreateAilySessionRunRequest.builder() \
            .aily_session_id(aily_session_id) \
            .request_body(CreateAilySessionRunRequestBody.builder()
                          .app_id(self.aily_app_id)
                          .build()) \
            .build()
        # 发起请求
        option = lark.RequestOption.builder().user_access_token(
            access_token).build()
        response: CreateAilySessionRunResponse = self.ulark_client.aily.v1.aily_session_run.create(request, option)
        # 处理失败返回
        if not response.success():
            lark.logger.error(
                f"client.aily.v1.aily_session_run.create failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
            return

        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.data, indent=4))


if __name__ == '__main__':
    aily_app_id = AilyLarkClient({}).get_tenant_access_token()
